@@ -161,7 +161,7 @@ def _decompress_single_file_gzip(file_path):
                 _f.write(temp_path, contents)
     except _gzip.BadGzipFile:
         # print(f"File is not compressed: {file_path}")
-        return _f.read(file_path)
+        return _f.readr(file_path)
 
     if contents is not False:
         # delete the compressed file
@@ -174,7 +174,7 @@ def _decompress_single_file_gzip(file_path):
 def _compress_single_file_gzip(file_path):
     success = False
     try:
-        contents = _f.read(file_path)
+        contents = _f.readr(file_path)
         with _gzip.open(file_path, 'wb') as target_file:
             target_file.write(contents.encode())
             success = True
@@ -1043,7 +1043,10 @@ def get_name_no_ext(file_path):
         `version`: 1.0
         `method_name`: get_name_no_ext
     '''
-    return _os.path.basename(file_path).replace(get_ext(file_path), '')
+    value = _os.path.basename(file_path).replace(get_ext(file_path), '')
+    if value is None:
+        value = ""
+    return value
 
 
 def gen_relative_path(src_base, dst_base, file_path):
@@ -1221,7 +1224,6 @@ def gen_src_path(src_base, dst_base, file_path):
     relative_path = gen_relative_path(src_base, dst_base, file_path)
     return _csu.file_path(f"{src_base}/{relative_path}")
 
-
 def get_files(search_path=False, **kwargs):
     '''
         Get all files/data from the search_path.
@@ -1245,9 +1247,12 @@ def get_files(search_path=False, **kwargs):
                 if equal to "images" it will automatically search for these extensions:
                     bmp,dds,dib,eps,gif,icns,ico,im,jpg,jpeg,jpeg 2000,msp,pcx,png,ppm,sgi,spider,tga,tiff,webp,xbm
 
-            [`show count`=True] {bool}
+            [`show count`=False] {bool}
                 If True, the index count is printed to the terminal during indexing.
 
+            [`dicts`=True] {bool}
+                if True, this will return a list of dictionaries, otherwise it will return a list of File objects.
+
             [`threaded`=True] {bool}
                 if True, the process is multi-threaded,
                 this makes indexing much faster,
@@ -1293,6 +1298,7 @@ def get_files(search_path=False, **kwargs):
     if isinstance(search_path, list) is False:
         search_path = [search_path]
 
+    dicts = _obj.get_kwarg(['dicts'], True, bool, **kwargs)
     threaded = _obj.get_kwarg(['threaded', 'thread'], True, bool, **kwargs)
     recursive = _obj.get_kwarg(['recursive', 'recurse'], True, bool, **kwargs)
 
@@ -1319,7 +1325,7 @@ def get_files(search_path=False, **kwargs):
     if isinstance(include, (str)):
         include = [include]
 
-    show_index_count = _obj.get_kwarg(['show_index_count', 'show count'], True, bool, **kwargs)
+    show_index_count = _obj.get_kwarg(['show_index_count', 'show count'], False, bool, **kwargs)
 
     # print(f"file.get_files.kwarg['extension']: ",_obj.get_kwarg(['extensions', 'ext', 'extension'], [], (str, list), **kwargs))
     extension_array = _obj.get_kwarg(['extensions', 'ext', 'extension'], [], (str, list), **kwargs)
@@ -1335,7 +1341,15 @@ def get_files(search_path=False, **kwargs):
     if threaded is True:
         # print(f"file.get_files - Using threads for indexing.")
         for path in search_path:
-            gft = GetFilesThreaded(path, recursive=recursive, data_include=data_include, exclude=exclude, include=include, extensions=extension_array,include_meta_data=include_meta_data,show_index_count=show_index_count)
+            gft = GetFilesThreaded(path,
+                recursive=recursive,
+                data_include=data_include,
+                exclude=exclude,
+                include=include,
+                extensions=extension_array,
+                include_meta_data=include_meta_data,
+                dicts=dicts,
+                show_index_count=show_index_count)
             return gft.master()
     # print(_json.dumps(extension_array, indent=4))
     for path in search_path:
@@ -1591,6 +1605,7 @@ class GetFilesThreaded:
         if isinstance(self.search_path, list) is False:
             self.search_path = [self.search_path]
 
+        self.dicts = _obj.get_kwarg(['dicts'], True, bool, **kwargs)
         self.recursive = _obj.get_kwarg(['recursive', 'recurse'], True, bool, **kwargs)
 
         self.data_include = _obj.get_kwarg(['data include'], [], (list, str), **kwargs)
@@ -1662,6 +1677,9 @@ class GetFilesThreaded:
                 if file_ext not in self.extension_array:
                     return
 
+        if self.dicts is False:
+            file_data = _f.File(file_path,file_data)
+
         self.file_array.append(file_data)
         if self.show_index_count is True:
             print(f"files indexed: {len(self.file_array)}                                             ",end="\r",flush=True)
