@@ -18,6 +18,7 @@
 # import json
 # import hashlib
 import logging as _logging
+import config as _config
 from typing import Union as _Union
 import re as _re
 import os as _os
@@ -889,234 +890,61 @@ def dict_replace_string(value:str,replace:dict):
             value = value.replace(k,v)
     return value
 
+def plural_noun(value:str):
+    '''
+        Convert the string (noun) to its plural equivalent.
+
+        This uses the inflect library to perform the smart stuff..
+
+        ----------
+
+        Arguments
+        -------------------------
+        `value` {str}
+            The string to convert to plural
+
+        Return {str}
+        ----------------------
+        The plural equivalent of the noun.
+
+        Meta
+        ----------
+        `author`: Colemen Atwood
+        `created`: 07-05-2022 07:56:17
+        `memberOf`: string_format
+        `version`: 1.0
+        `method_name`: plural_noun
+        * @xxx [07-05-2022 07:58:44]: documentation for plural_noun
+    '''
+
+    p = _config.inflect_engine()
+    return p.plural_noun(value)
+
+def singular_noun(value:str):
+    '''
+        Convert a string (noun) to its singular equivalent.
+        
+        This uses the inflect library to perform the smart stuff..        
+
+        Arguments
+        -------------------------
+        `value` {str}
+            The string to convert to singular.
+
+        Return {str}
+        ----------------------
+        The singular equivalent of the noun.
+
+        Meta
+        ----------
+        `author`: Colemen Atwood
+        `created`: 07-05-2022 07:54:50
+        `memberOf`: string_format
+        `version`: 1.0
+        `method_name`: singular_noun
+        * @xxx [07-05-2022 07:59:39]: documentation for singular_noun
+    '''
 
 
-
-# def _get_numeric_charcode(char):
-#     for _,v in _numeric_char_codes.items():
-#         for c,code in v.items():
-#             if c == char:
-#                 return code
-#     return None
-
-# def _get_numeric_charcode_chars(cat:str)->list:
-#     output = []
-#     if cat in _numeric_char_codes:
-#         for k,_ in _numeric_char_codes[cat].items():
-#             output.append(k)
-#     return output
-
-# def charcode_escape(value:str,**kwargs)->str:
-#     '''
-#         Escape character in a string with their character codes.
-
-#         ----------
-
-#         Arguments
-#         -------------------------
-#         `value` {str}
-#             The string to escape.
-
-#         Keyword Arguments
-#         -------------------------
-#         `chars` {list|str}
-#             A list or string of characters to escape.
-#         [`symbols`=True] {bool}
-#             If True, all symbols will be escaped.
-#         [`numeric`=False] {bool}
-#             If True, all numeric will be escaped.
-#         [`upper_case`=False] {bool}
-#             If True, all upper_case will be escaped.
-#         [`lower_case`=False] {bool}
-#             If True, all lower_case will be escaped.
-
-#         Return {str}
-#         ----------------------
-#         The escaped string.
-
-#         Meta
-#         ----------
-#         `author`: Colemen Atwood
-#         `created`: 06-04-2022 09:36:42
-#         `memberOf`: string_format
-#         `version`: 1.0
-#         `method_name`: charcode_escape
-#         * @xxx [06-04-2022 09:38:48]: documentation for charcode_escape
-#     '''
-
-
-#     chars = _obj.get_kwarg(["chars"], None, (list,str), **kwargs)
-#     symbols = _obj.get_kwarg(["symbols"], True, (bool), **kwargs)
-#     numeric = _obj.get_kwarg(["numeric"], False, (bool), **kwargs)
-#     upper_case = _obj.get_kwarg(["upper_case"], False, (bool), **kwargs)
-#     lower_case = _obj.get_kwarg(["lower_case"], False, (bool), **kwargs)
-
-#     if chars is not None:
-#         if isinstance(chars,(str)):
-#             chars = chars.split()
-#         for c in chars:
-#             code = _get_numeric_charcode(c)
-#             value = value.replace(c,code)
-#         return value
-
-#     chars = []
-
-#     if symbols is True:
-#         chars = chars + _get_numeric_charcode_chars('symbols')
-#     if numeric is True:
-#         chars = chars + _get_numeric_charcode_chars('numeric')
-#     if upper_case is True:
-#         chars = chars + _get_numeric_charcode_chars('upper_case')
-#     if lower_case is True:
-#         chars = chars + _get_numeric_charcode_chars('lower_case')
-
-#     for c in chars:
-#         code = _get_numeric_charcode(c)
-#         value = value.replace(c,code)
-
-#     return value
-
-# def charcode_unescape(value:str)->str:
-#     '''
-#         Unescape the character codes from charcode_escape.
-
-#         ----------
-
-#         Arguments
-#         -------------------------
-#         `value` {str}
-#             The string to unescape.
-
-#         Return {str}
-#         ----------------------
-#         The unescaped string.
-
-#         Meta
-#         ----------
-#         `author`: Colemen Atwood
-#         `created`: 06-04-2022 09:39:02
-#         `memberOf`: string_format
-#         `version`: 1.0
-#         `method_name`: charcode_unescape
-#         * @xxx [06-04-2022 09:39:50]: documentation for charcode_unescape
-#     '''
-
-#     for _,v in _numeric_char_codes.items():
-#         for c,code in v.items():
-#             value = value.replace(code,c)
-#     return value
-
-
-
-
-# def escape_quoted_commas(value,escape_value="__ESCAPED_COMMA__",reverse=False):
-#     '''
-#         Escape commas that are located within quotes.
-
-#         ----------
-
-#         Arguments
-#         -------------------------
-#         `value` {str}
-#             The string to search within
-#         [`escape_value`='__ESCAPED_COMMA__] {str}
-#             The value to replace commas with.
-#         `reverse` {bool}
-#             if True it will replace the escaped commas with actual commas.
-
-#         Return {str}
-#         ----------------------
-#         The string with escaped commas.
-
-#         Meta
-#         ----------
-#         `author`: Colemen Atwood
-#         `created`: 06-01-2022 06:54:48
-#         `memberOf`: parse_sql
-#         `version`: 1.0
-#         `method_name`: escape_quoted_commas
-#         @xxx [06-01-2022 06:57:45]: documentation for escape_quoted_commas
-#     '''
-
-#     if reverse is True:
-#         return value.replace(escape_value,",")
-
-#     sql_qs = QuotedString("'", esc_quote="''")
-#     quote = sql_qs.search_string(value)
-#     if len(quote) > 0:
-#         quote = quote.asList()
-#         # print(f"quote: {quote}")
-#         for q in quote:
-#             if len(q) == 1:
-#                 q = q[0]
-#             esc = q.replace(",",escape_value)
-#             value = value.replace(q,esc)
-
-#     # print(sql_qs.search_string(value))
-#     return value
-
-# def escape_quoted_chars(value,reverse=False):
-#     '''
-#         Escape characters that can effect parsing which are located within quotes.
-
-#         ----------
-
-#         Arguments
-#         -------------------------
-#         `value` {str}
-#             The string to search within
-
-#         `reverse` {bool}
-#             if True it will reverse the escaped chars with their actual chars.
-
-#         Return {str}
-#         ----------------------
-#         The string with escaped chars.
-
-#         Meta
-#         ----------
-#         `author`: Colemen Atwood
-#         `created`: 06-01-2022 06:54:48
-#         `memberOf`: parse_sql
-#         `version`: 1.0
-#         `method_name`: escape_quoted_chars
-#         @xxx [06-01-2022 06:57:45]: documentation for escape_quoted_chars
-#     '''
-
-#     escapes = [
-#         [",","__&#44__"],
-#         [";","__&#59__"],
-#         ["(","__&#40__"],
-#         [")","__&#41__"],
-#         ["`","__&#96__"],
-#         ['"',"__&#34__"],
-#         ["'","__&#39__"],
-#     ]
-
-
-#     if reverse is True:
-#         for e in escapes:
-#             value = value.replace(e[1],e[0])
-#         return value
-
-#     for e in escapes:
-#         sql_qs = QuotedString("'", esc_quote="''")
-#         quote = sql_qs.search_string(value)
-#         if len(quote) > 0:
-#             quote = quote.asList()
-#             # print(f"quote: {quote}")
-#             for q in quote:
-#                 if len(q) == 1:
-#                     q = q[0]
-#                 esc = q.replace(e[0],e[1])
-#                 value = value.replace(q,esc)
-#     # print(sql_qs.search_string(value))
-#     return value
-
-
-
-
-
-# ----------========== ALIASES ==========----------
-left_pad = leftPad
-
+    p = _config.inflect_engine()
+    return p.singular_noun(value)
